# Roadmap

## Immediate Goals

- Update the README to include installation, usage, and development instructions
- Publish the package
- Improve the model download workflow
  - Reject incompatible models with a helpful message
  - Custom message when downloading a model; don't supress progress bar otherwise

## Considering

- Add `py.typed`
- Have pre-configured prompts for different usecases
- CLI workflow for downloading and managing models

